package com.mdd.admin.validate.article;

import com.mdd.common.validator.annotation.IDMust;
import com.mdd.common.validator.annotation.IntegerContains;
import io.swagger.annotations.ApiModel;
import io.swagger.annotations.ApiModelProperty;
import java.io.Serializable;
import javax.validation.constraints.DecimalMin;
import javax.validation.constraints.NotEmpty;
import javax.validation.constraints.NotNull;
import org.hibernate.validator.constraints.Length;

@ApiModel("文章创建参数")
public class ArticleCreateValidate implements Serializable {
   private static final long serialVersionUID = 1L;
   @IDMust(
      message = "cid参数必传且需大于0"
   )
   @ApiModelProperty(
      value = "分类ID",
      required = true
   )
   private Integer cid;
   @ApiModelProperty(
      value = "文章标题",
      required = true
   )
   private @NotEmpty(
   message = "文章标题不能为空"
) @Length(
   min = 1,
   max = 200,
   message = "文章标题不能大于200个字符"
) String title;
   @ApiModelProperty("文章简介")
   private @Length(
   max = 200,
   message = "简介不能超出200个字符"
) String intro = "";
   @ApiModelProperty("封面图片")
   private @Length(
   max = 200,
   message = "图片链接过长不能超200个字符"
) String image = "";
   @ApiModelProperty("作者姓名")
   private @Length(
   max = 32,
   message = "作者名称不能超32个字符"
) String author = "";
   @ApiModelProperty(
      value = "排序",
      required = true
   )
   private @NotNull(
   message = "排序号不能为空"
) @DecimalMin(
   value = "0",
   message = "排序号值不能少于0"
) Integer sort;
   @IntegerContains(
      values = {0, 1},
      message = "isShow不是合法值"
   )
   @ApiModelProperty(
      value = "是否显示",
      required = true
   )
   private @NotNull(
   message = "缺少isShow参数"
) Integer isShow;
   @ApiModelProperty("文章内容")
   private String content = "";
   @ApiModelProperty("文章描述")
   private String summary = "";
   @ApiModelProperty("浏览数量")
   private @DecimalMin(
   value = "0",
   message = "初始浏览量不能少于0"
) Integer visit = 0;

   public Integer getCid() {
      return this.cid;
   }

   public String getTitle() {
      return this.title;
   }

   public String getIntro() {
      return this.intro;
   }

   public String getImage() {
      return this.image;
   }

   public String getAuthor() {
      return this.author;
   }

   public @NotNull(
   message = "排序号不能为空"
) Integer getSort() {
      return this.sort;
   }

   public @NotNull(
   message = "缺少isShow参数"
) Integer getIsShow() {
      return this.isShow;
   }

   public String getContent() {
      return this.content;
   }

   public String getSummary() {
      return this.summary;
   }

   public Integer getVisit() {
      return this.visit;
   }

   public void setCid(Integer cid) {
      this.cid = cid;
   }

   public void setTitle(String title) {
      this.title = title;
   }

   public void setIntro(String intro) {
      this.intro = intro;
   }

   public void setImage(String image) {
      this.image = image;
   }

   public void setAuthor(String author) {
      this.author = author;
   }

   public void setSort(@NotNull(
   message = "排序号不能为空"
) Integer sort) {
      this.sort = sort;
   }

   public void setIsShow(@NotNull(
   message = "缺少isShow参数"
) Integer isShow) {
      this.isShow = isShow;
   }

   public void setContent(String content) {
      this.content = content;
   }

   public void setSummary(String summary) {
      this.summary = summary;
   }

   public void setVisit(Integer visit) {
      this.visit = visit;
   }

   public boolean equals(Object o) {
      if (o == this) {
         return true;
      } else if (!(o instanceof ArticleCreateValidate)) {
         return false;
      } else {
         ArticleCreateValidate other = (ArticleCreateValidate)o;
         if (!other.canEqual(this)) {
            return false;
         } else {
            Object this$cid = this.getCid();
            Object other$cid = other.getCid();
            if (this$cid == null) {
               if (other$cid != null) {
                  return false;
               }
            } else if (!this$cid.equals(other$cid)) {
               return false;
            }

            Object this$sort = this.getSort();
            Object other$sort = other.getSort();
            if (this$sort == null) {
               if (other$sort != null) {
                  return false;
               }
            } else if (!this$sort.equals(other$sort)) {
               return false;
            }

            Object this$isShow = this.getIsShow();
            Object other$isShow = other.getIsShow();
            if (this$isShow == null) {
               if (other$isShow != null) {
                  return false;
               }
            } else if (!this$isShow.equals(other$isShow)) {
               return false;
            }

            label110: {
               Object this$visit = this.getVisit();
               Object other$visit = other.getVisit();
               if (this$visit == null) {
                  if (other$visit == null) {
                     break label110;
                  }
               } else if (this$visit.equals(other$visit)) {
                  break label110;
               }

               return false;
            }

            label103: {
               Object this$title = this.getTitle();
               Object other$title = other.getTitle();
               if (this$title == null) {
                  if (other$title == null) {
                     break label103;
                  }
               } else if (this$title.equals(other$title)) {
                  break label103;
               }

               return false;
            }

            Object this$intro = this.getIntro();
            Object other$intro = other.getIntro();
            if (this$intro == null) {
               if (other$intro != null) {
                  return false;
               }
            } else if (!this$intro.equals(other$intro)) {
               return false;
            }

            label89: {
               Object this$image = this.getImage();
               Object other$image = other.getImage();
               if (this$image == null) {
                  if (other$image == null) {
                     break label89;
                  }
               } else if (this$image.equals(other$image)) {
                  break label89;
               }

               return false;
            }

            label82: {
               Object this$author = this.getAuthor();
               Object other$author = other.getAuthor();
               if (this$author == null) {
                  if (other$author == null) {
                     break label82;
                  }
               } else if (this$author.equals(other$author)) {
                  break label82;
               }

               return false;
            }

            Object this$content = this.getContent();
            Object other$content = other.getContent();
            if (this$content == null) {
               if (other$content != null) {
                  return false;
               }
            } else if (!this$content.equals(other$content)) {
               return false;
            }

            Object this$summary = this.getSummary();
            Object other$summary = other.getSummary();
            if (this$summary == null) {
               if (other$summary != null) {
                  return false;
               }
            } else if (!this$summary.equals(other$summary)) {
               return false;
            }

            return true;
         }
      }
   }

   protected boolean canEqual(Object other) {
      return other instanceof ArticleCreateValidate;
   }

   public int hashCode() {
      int PRIME = true;
      int result = 1;
      Object $cid = this.getCid();
      result = result * 59 + ($cid == null ? 43 : $cid.hashCode());
      Object $sort = this.getSort();
      result = result * 59 + ($sort == null ? 43 : $sort.hashCode());
      Object $isShow = this.getIsShow();
      result = result * 59 + ($isShow == null ? 43 : $isShow.hashCode());
      Object $visit = this.getVisit();
      result = result * 59 + ($visit == null ? 43 : $visit.hashCode());
      Object $title = this.getTitle();
      result = result * 59 + ($title == null ? 43 : $title.hashCode());
      Object $intro = this.getIntro();
      result = result * 59 + ($intro == null ? 43 : $intro.hashCode());
      Object $image = this.getImage();
      result = result * 59 + ($image == null ? 43 : $image.hashCode());
      Object $author = this.getAuthor();
      result = result * 59 + ($author == null ? 43 : $author.hashCode());
      Object $content = this.getContent();
      result = result * 59 + ($content == null ? 43 : $content.hashCode());
      Object $summary = this.getSummary();
      result = result * 59 + ($summary == null ? 43 : $summary.hashCode());
      return result;
   }

   public String toString() {
      return "ArticleCreateValidate(cid=" + this.getCid() + ", title=" + this.getTitle() + ", intro=" + this.getIntro() + ", image=" + this.getImage() + ", author=" + this.getAuthor() + ", sort=" + this.getSort() + ", isShow=" + this.getIsShow() + ", content=" + this.getContent() + ", summary=" + this.getSummary() + ", visit=" + this.getVisit() + ")";
   }
}
